@@ -17,7 +17,6 @@
 #
 # ************************************************************************
 
-
 # --------------------------------
 #
 # --------------------------------
@@ -57,9 +56,7 @@ class CostExplorer(Base):
 
         self.cost_explorer = self.session.client(
             "ce",
-            config=botocore.config.Config(
-                connect_timeout=5, retries={"max_attempts": 0}
-            ),
+            config=botocore.config.Config(connect_timeout=5, retries={"max_attempts": 0}),
         )
 
         self.df_accounts = None
@@ -150,7 +147,6 @@ class CostExplorer(Base):
         results = []
 
         while not done:
-
             # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce/client/get_cost_and_usage.html
             response = self.cost_explorer.get_cost_and_usage(**params)
             if "NextPageToken" in response:
@@ -233,10 +229,7 @@ class CostExplorer(Base):
 
         # Process all entries to store in Pandas dataframe
         for result in results:
-
-            dt_day = datetime.datetime.strptime(
-                result["TimePeriod"]["Start"], "%Y-%m-%d"
-            )
+            dt_day = datetime.datetime.strptime(result["TimePeriod"]["Start"], "%Y-%m-%d")
             total_costs.append(
                 {
                     "Date": dt_day,
@@ -281,12 +274,8 @@ class CostExplorer(Base):
 
         # Process all entries to store in Pandas dataframe
         for result in results:
-
-            dt_day = datetime.datetime.strptime(
-                result["TimePeriod"]["Start"], "%Y-%m-%d"
-            )
+            dt_day = datetime.datetime.strptime(result["TimePeriod"]["Start"], "%Y-%m-%d")
             for group in result.get("Groups", []):
-
                 key = group["Keys"][0]
                 if group_type == "TAG":
                     key = key.removeprefix(f"{group_key}$").lower()
@@ -339,9 +328,7 @@ class CostExplorer(Base):
         """Get list of accounts"""
 
         if self.df_accounts is None:
-            linked_accounts = [
-                {"Id": "na", "Name": "na", "Email": "na", "Status": "na"}
-            ]
+            linked_accounts = [{"Id": "na", "Name": "na", "Email": "na", "Status": "na"}]
             try:
                 linked_accounts = (
                     o7cli.organizations.Organizations(session=self.session)
@@ -471,7 +458,6 @@ class CostExplorer(Base):
         tags = self.load_tags()
 
         while True:
-
             self.console_title(left="Avalable Costing Tags")
             print("-----------------------------")
             print("Avalable Costing Tags")
@@ -519,7 +505,6 @@ class CostExplorer(Base):
         ]
 
         while True:
-
             self.console_title(left="Avalable Costing Dimensions")
             print("Avalable Costing Dimensions")
             for i, dimension in enumerate(dimensions):
@@ -542,7 +527,6 @@ class CostExplorer(Base):
         accounts = self.load_accounts()
 
         while True:
-
             self.console_title(left="Linked Account List")
             print(accounts[["Id", "Name", "Email", "Status"]])
             key = o7util.input.input_multi("Option -> Back(b) Select(int): ")
@@ -575,7 +559,6 @@ class CostExplorer(Base):
         )  # https://docs.python.org/2/library/string.html#formatstrings
 
         while True:
-
             if show_raw:
                 df_costs_with_sum = self.df_costs.copy()
                 df_costs_with_sum.loc["Total"] = self.df_costs.sum()
@@ -622,10 +605,7 @@ class CostExplorer(Base):
 
                 if key == "x":
                     filename = f"aws-cost-{datetime.datetime.now().isoformat()[0:19].replace(':','-')}.xlsx"
-                    with pd.ExcelWriter(
-                        filename
-                    ) as writer:  # pylint: disable=abstract-class-instantiated
-
+                    with pd.ExcelWriter(filename) as writer:  # pylint: disable=abstract-class-instantiated
                         df_parameters = pd.DataFrame(
                             [
                                 {
@@ -651,7 +631,6 @@ class CostExplorer(Base):
                 and not show_raw
                 and 0 <= key < len(self.df_costs_summarize.index)
             ):
-
                 value = self.df_costs_summarize.loc[key][self.group_key]
                 print(f"Getting Detailed for value: {value}")
 
@@ -690,7 +669,6 @@ def menu(**kwargs):
 #
 # *************************************************
 if __name__ == "__main__":
-
     the_ce = CostExplorer()
     CostExplorer().menu()
 
